==> haskell-vector-th-unbox-0.2.2-645.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-vector-th-unbox.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 vector-th-unbox
version:              0.2.2
visibility:           public
id:                   vector-th-unbox-0.2.2-ImcSwt94EHZJi6PFnaUEjq
key:                  vector-th-unbox-0.2.2-ImcSwt94EHZJi6PFnaUEjq
license:              BSD-3-Clause
copyright:            (c) 2012-2015 Liyang HU
maintainer:           Fumiaki Kinoshita <fumiexcel@gmail.com>
author:               Liyang HU <vector-th-unbox@liyang.hu>
stability:            experimental
homepage:             https://github.com/tsurucapital/vector-th-unbox
synopsis:             Deriver for Data.Vector.Unboxed using Template Haskell
description:
    A Template Haskell deriver for unboxed vectors, given a pair of coercion
    functions to and from some existing type with an Unbox instance.

    Refer to "Data.Vector.Unboxed.Deriving" for documentation and examples.

category:             Data
abi:                  3f7ae5d0ca21126eaaa0585f271c5f02
exposed:              True
exposed-modules:      Data.Vector.Unboxed.Deriving
import-dirs:          /usr/lib/ghc-9.6.6/site-local/vector-th-unbox-0.2.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/vector-th-unbox-0.2.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/vector-th-unbox-0.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vector-th-unbox
hs-libraries:         HSvector-th-unbox-0.2.2-ImcSwt94EHZJi6PFnaUEjq
depends:
    base-4.18.2.1 template-haskell-2.20.0.0
    vector-0.13.2.0-L5lYsWFgdBEAgjlr9nnpMP

haddock-interfaces:
    /usr/share/doc/haskell-vector-th-unbox/html/vector-th-unbox.haddock

haddock-html:         /usr/share/doc/haskell-vector-th-unbox/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vector-th-unbox-0.2.2-648-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-vector-th-unbox.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 vector-th-unbox
version:              0.2.2
visibility:           public
id:                   vector-th-unbox-0.2.2-HC5jNvwwS6Y1jBxTSVdusQ
key:                  vector-th-unbox-0.2.2-HC5jNvwwS6Y1jBxTSVdusQ
license:              BSD-3-Clause
copyright:            (c) 2012-2015 Liyang HU
maintainer:           Fumiaki Kinoshita <fumiexcel@gmail.com>
author:               Liyang HU <vector-th-unbox@liyang.hu>
stability:            experimental
homepage:             https://github.com/tsurucapital/vector-th-unbox
synopsis:             Deriver for Data.Vector.Unboxed using Template Haskell
description:
    A Template Haskell deriver for unboxed vectors, given a pair of coercion
    functions to and from some existing type with an Unbox instance.

    Refer to "Data.Vector.Unboxed.Deriving" for documentation and examples.

category:             Data
abi:                  b4835d148c42648c967867db1ecf8b58
exposed:              True
exposed-modules:      Data.Vector.Unboxed.Deriving
import-dirs:          /usr/lib/ghc-9.6.6/site-local/vector-th-unbox-0.2.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/vector-th-unbox-0.2.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/vector-th-unbox-0.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vector-th-unbox
hs-libraries:         HSvector-th-unbox-0.2.2-HC5jNvwwS6Y1jBxTSVdusQ
depends:
    base-4.18.2.1 template-haskell-2.20.0.0
    vector-0.13.2.0-eGaPlIkScLKlfBYQuI3vH

haddock-interfaces:
    /usr/share/doc/haskell-vector-th-unbox/html/vector-th-unbox.haddock

haddock-html:         /usr/share/doc/haskell-vector-th-unbox/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
